@@ -13,12 +13,17 @@
 
 #include <QStringList>
 #include <QFileSystemWatcher>
+#include <QQmlEngine>
 
 class ELISALIB_EXPORT ElisaConfigurationDialog : public QObject
 {
 
     Q_OBJECT
 
+    QML_ELEMENT
+
+    QML_SINGLETON
+
     Q_PROPERTY(QStringList rootPath
                READ rootPath
                WRITE setRootPath
@@ -85,6 +90,13 @@ class ELISALIB_EXPORT ElisaConfigurationDialog : public QObject
 
 public:
 
+    static ElisaConfigurationDialog *create(QQmlEngine *engine, QJSEngine *scriptEngine)
+    {
+        Q_UNUSED(engine)
+        Q_UNUSED(scriptEngine)
+        return new ElisaConfigurationDialog;
+    }
+
     explicit ElisaConfigurationDialog(QObject *parent = nullptr);
 
     ~ElisaConfigurationDialog() override;
